# 異なるバージョンの互換性

この実験は新しいバージョンのOpenSesameで作成されました。

現在使用しているバージョンのOpenSesameで正常に動作することは保証されていません。最新のバージョンにアップデートすることをおすすめします。もしアップデートができない場合は、この実験ファイルを別名で保存することをおすすめします。

実験ファイルの操作

[実験を保存する](opensesame://action.save){: .important-button} <br />

もしくは:

[今後このメッセージを表示しない](opensesame://event.os3n_dismiss_old_experiment){: .dismiss-button}
